==> mgb-0.6.9.2.tar.gz: language/lang_dutch_utf8/lang_import.php <==
<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// ======================= //
	// lang_import.php - Dutch //
	// ======================= //
	//
	// This languagefile was translated by Gerard Vandeninden gerard@brookstruefriends.nl

	// header
	$lang['h_title'] = "Database-import van een oudere versie";

	// general
	$lang['next_step'] = "&raquo; volgende &raquo;";
	$lang['yes'] = "ja";
	$lang['no'] = "nee";
	$lang['active'] = "actief";
	$lang['inactive'] = "inactief";
	$lang['ok'] = "OK!";
	$lang['not_ok'] = "mislukt!";

	// installation
	$lang['title'] = "Database-import van een oudere versie";
	
	$lang['expl_import'] = "Geef de verbindings info voor de database waar de oude installatie van MGB staat. Vervolgens het absolute pad naar de oude installatie <b>zonder de domeinnaam</b>. Voorbeeld: inplaats van <i>http://www.example.com/php/mgb/</i> alleen <i>/php/mgb/</i>. Let op de slashes aan het begin en het eind.";

	// step 1
	$lang['db_title'] = "Database-details:";
	$lang['db_hostname'] = "host:";
	$lang['db_dbname'] = "database naam:";
	$lang['db_username'] = "usernaam:";
	$lang['db_password'] = "wachtwoord:";
	$lang['oldgb_path'] = "pad:";
	$lang['import_settings'] = "import instellingen:";

	// errormessages step 1
	$lang['no_error'] = "Alle waarden zijn OK!";
	$lang['error_1_step1'] = "vul a.u.b. alle velden in!";
	$lang['error_2_step1'] = "De connectie met de database kan niet gemaakt worden. Controleer de verbindings instellingen!";
	$lang['error_3_step1'] = "OP het opgegeven pad werd geen MGB installatie aangetroffen!";
	$lang['error_4_step1'] = "De opgegeven database is  OK, maar er kon geen vorige installatie gevonden worden.!";

	// step 2
	$lang['transfer_settings'] = "settings overzetten...";
	$lang['transfer_entries'] = "berichten importeren...";

	// finish
	$lang['import_finish'] = "Gefeliciteerd!<br><br>De data van de oude MGB installatie is succesvol overgezet naar de MGB ".MGB_VERSION.". <br><br><a href='../admin/admin.php' title='Naar de administratie pagina'>Naar de administratie pagina</a><br><a href='../index.php' title='Naar het gastenboek'>Naar het gastenboek</a>";
?>

==> mgb-0.6.9.5.tar.gz: language/lang_dutch_utf8/lang_import.php <==
<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2013 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// =======================
	// lang_import.php - Dutch
	// =======================
	//
	// This languagefile was translated by Gerard Vandeninden gerard@brookstruefriends.nl
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

	// header
	$lang['h_title'] = "Database-import van een oudere versie";

	// general
	$lang['next_step'] = "&raquo; volgende &raquo;";
	$lang['yes'] = "ja";
	$lang['no'] = "nee";
	$lang['active'] = "actief";
	$lang['inactive'] = "inactief";
	$lang['ok'] = "OK!";
	$lang['not_ok'] = "mislukt!";

	// installation
	$lang['title'] = "Database-import van een oudere versie";

	$lang['expl_import'] = "Geef de verbindings info voor de database waar de oude installatie van MGB staat. Vervolgens het absolute pad naar de oude installatie <b>zonder de domeinnaam</b>. Voorbeeld: inplaats van <i>http://www.example.com/php/mgb/</i> alleen <i>/php/mgb/</i>. Let op de slashes aan het begin en het eind.";

	// step 1
	$lang['db_title'] = "Database-details:";
	$lang['db_hostname'] = "host:";
	$lang['db_dbname'] = "database naam:";
	$lang['db_username'] = "usernaam:";
	$lang['db_password'] = "wachtwoord:";
	$lang['oldgb_path'] = "pad:";
	$lang['import_settings'] = "import instellingen:";

	// errormessages step 1
	$lang['no_error'] = "Alle waarden zijn OK!";
	$lang['error_1_step1'] = "vul a.u.b. alle velden in!";
	$lang['error_2_step1'] = "De connectie met de database kan niet gemaakt worden. Controleer de verbindings instellingen!";
	$lang['error_3_step1'] = "OP het opgegeven pad werd geen MGB installatie aangetroffen!";
	$lang['error_4_step1'] = "De opgegeven database is  OK, maar er kon geen vorige installatie gevonden worden.!";

	// step 2
	$lang['transfer_settings'] = "settings overzetten...";
	$lang['transfer_entries'] = "berichten importeren...";

	// finish
	$lang['import_finish'] = "Gefeliciteerd!<br><br>De data van de oude MGB installatie is succesvol overgezet naar de MGB ".MGB_VERSION.". <br><br><a href='../admin/admin.php' title='Naar de administratie pagina'>Naar de administratie pagina</a><br><a href='../index.php' title='Naar het gastenboek'>Naar het gastenboek</a>";
?>
